==> heat-2024.2.3+6b985e51b.tgz: heat/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Remove tls values override for clients_heat
- 0.1.3 Change Issuer to ClusterIssuer
- 0.1.4 Revert - Change Issuer to ClusterIssuer
- 0.1.5 Change Issuer to ClusterIssuer
- 0.2.0 Remove support for releases before T
- 0.2.1 Adding rabbitmq TLS logic
- 0.2.2 Use policies in yaml format
- 0.2.3 Mount rabbitmq TLS secret
- 0.2.4 Add Ussuri release support
- 0.2.5 Add Victoria and Wallaby releases support
- 0.2.6 Added post-install and post-upgrade helm-hook for jobs
- 0.2.7 Helm 3 - Fix Job Labels
- 0.2.8 Update htk requirements repo
- 0.2.9 Enable taint toleration for Openstack services
- 0.2.10 Updated naming for subchart compatibility
- 0.2.11 Remove old releases values override in heat
- 0.2.12 Migrated CronJob resource to batch/v1 API version & PodDisruptionBudget to policy/v1
- 0.2.13 Add Xena and Yoga values overrides
- 0.2.14 Added OCI registry authentication
- 0.2.15 Distinguish between port number of internal endpoint and binding port number
- 0.2.16 Support TLS endpoints
- 0.2.17 Use HTTP probe instead of TCP probe
- 0.2.18 Change hook weight for bootstrap job
- 0.3.0 Remove support for Train and Ussuri
- 0.3.1 Remove default policy rules
- 0.3.2 Replace node-role.kubernetes.io/master with control-plane
- 0.3.3 Define service_type in keystone_authtoken to support application credentials with access rules
- 0.3.4 Add Zed overrides
- 0.3.5 Add 2023.1 overrides
- 0.3.6 Add Ubuntu Jammy overrides
- 0.3.7 Add 2023.2 Ubuntu Jammy overrides
- 0.3.8 Fixed annotation indentation for jobs
- 0.3.9 Uses uWSGI for API services
- 0.3.10 Enable custom annotations for Openstack pods
- 0.3.11 Add 2024.1 overrides
- 0.3.12 Add readiness probe initial delay
- 0.3.13 Enable custom annotations for Openstack secrets
- 0.3.14 Update images used by default
- 0.3.15 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.3.16 Add 2024.2 Ubuntu Jammy overrides
- 0.3.17 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

==> heat-2025.1.4+35052e51b.tgz: heat/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

- Create heat and heat_trustee service users in a single job.
  This is to align with the helm-toolkit change regarding
  Keystone user creation job.

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Remove tls values override for clients_heat
- 0.1.3 Change Issuer to ClusterIssuer
- 0.1.4 Revert - Change Issuer to ClusterIssuer
- 0.1.5 Change Issuer to ClusterIssuer
- 0.2.0 Remove support for releases before T
- 0.2.1 Adding rabbitmq TLS logic
- 0.2.2 Use policies in yaml format
- 0.2.3 Mount rabbitmq TLS secret
- 0.2.4 Add Ussuri release support
- 0.2.5 Add Victoria and Wallaby releases support
- 0.2.6 Added post-install and post-upgrade helm-hook for jobs
- 0.2.7 Helm 3 - Fix Job Labels
- 0.2.8 Update htk requirements repo
- 0.2.9 Enable taint toleration for Openstack services
- 0.2.10 Updated naming for subchart compatibility
- 0.2.11 Remove old releases values override in heat
- 0.2.12 Migrated CronJob resource to batch/v1 API version & PodDisruptionBudget to policy/v1
- 0.2.13 Add Xena and Yoga values overrides
- 0.2.14 Added OCI registry authentication
- 0.2.15 Distinguish between port number of internal endpoint and binding port number
- 0.2.16 Support TLS endpoints
- 0.2.17 Use HTTP probe instead of TCP probe
- 0.2.18 Change hook weight for bootstrap job
- 0.3.0 Remove support for Train and Ussuri
- 0.3.1 Remove default policy rules
- 0.3.2 Replace node-role.kubernetes.io/master with control-plane
- 0.3.3 Define service_type in keystone_authtoken to support application credentials with access rules
- 0.3.4 Add Zed overrides
- 0.3.5 Add 2023.1 overrides
- 0.3.6 Add Ubuntu Jammy overrides
- 0.3.7 Add 2023.2 Ubuntu Jammy overrides
- 0.3.8 Fixed annotation indentation for jobs
- 0.3.9 Uses uWSGI for API services
- 0.3.10 Enable custom annotations for Openstack pods
- 0.3.11 Add 2024.1 overrides
- 0.3.12 Add readiness probe initial delay
- 0.3.13 Enable custom annotations for Openstack secrets
- 0.3.14 Update images used by default
- 0.3.15 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.3.16 Add 2024.2 Ubuntu Jammy overrides
- 0.3.17 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle
